@@ -195,6 +195,12 @@ module Aws
         end
       end
 
+      # @param [Hash] partition metadata
+      # @api private For Internal use only
+      def merge_metadata(partition_metadata)
+        default_partition_list.merge_metadata(partition_metadata)
+      end
+
       # @api private For internal use only.
       def clear
         default_partition_list.clear
@@ -204,7 +210,11 @@ module Aws
       # @return [PartitionList]
       # @api private
       def default_partition_list
-        @default_partition_list ||= PartitionList.build(defaults)
+        @default_partition_list ||= begin
+          partitions = PartitionList.build(defaults)
+          partitions.merge_metadata(default_metadata)
+          partitions
+        end
       end
 
       # @return [Hash]
@@ -217,6 +227,16 @@ module Aws
         end
       end
 
+      # @return [Hash]
+      # @api private
+      def default_metadata
+        @default_metadata ||= begin
+          path = File.expand_path('../../partitions-metadata.json', __FILE__)
+          defaults = JSON.parse(File.read(path), freeze: true)
+          defaults.merge('partitions' => defaults['partitions'].dup)
+        end
+      end
+
       # @return [Hash<String,String>] Returns a map of service module names
       #   to their id as used in the endpoints.json document.
       # @api private For internal use only.
@@ -298,9 +318,11 @@ module Aws
             'ConfigService' => 'config',
             'Connect' => 'connect',
             'ConnectCampaignService' => 'connect-campaigns',
+            'ConnectCases' => 'cases',
             'ConnectContactLens' => 'contact-lens',
             'ConnectParticipant' => 'participant.connect',
             'ConnectWisdomService' => 'wisdom',
+            'ControlTower' => 'controltower',
             'CostExplorer' => 'ce',
             'CostandUsageReportService' => 'cur',
             'CustomerProfiles' => 'profile',
@@ -375,6 +397,7 @@ module Aws
             'IoTEvents' => 'iotevents',
             'IoTEventsData' => 'data.iotevents',
             'IoTFleetHub' => 'api.fleethub.iot',
+            'IoTFleetWise' => 'iotfleetwise',
             'IoTJobsDataPlane' => 'data.jobs.iot',
             'IoTSecureTunneling' => 'api.tunneling.iot',
             'IoTSiteWise' => 'iotsitewise',
@@ -433,6 +456,7 @@ module Aws
             'Mgn' => 'mgn',
             'MigrationHub' => 'mgh',
             'MigrationHubConfig' => 'migrationhub-config',
+            'MigrationHubOrchestrator' => 'migrationhub-orchestrator',
             'MigrationHubRefactorSpaces' => 'refactor-spaces',
             'MigrationHubStrategyRecommendations' => 'migrationhub-strategy',
             'Mobile' => 'mobile',
@@ -517,6 +541,7 @@ module Aws
             'States' => 'states',
             'StorageGateway' => 'storagegateway',
             'Support' => 'support',
+            'SupportApp' => 'supportapp',
             'Synthetics' => 'synthetics',
             'Textract' => 'textract',
             'TimestreamQuery' => 'query.timestream',
